<?php

class MarkerSubBoard extends DataObject {

	static $db = array(
		"Code" => "Varchar(20)",
		"Name" => "Varchar(200)"
	);

	static $has_one = array(
		"Marker" => "MarkerBoard"
	);

	static $indexes = array(
		"Code" => true
	);

	static $default_sort = "\"Name\" ASC";

	public static $singular_name = "MarkerSub";
		function i18n_singular_name() { return _t("MarkerSubBoard.MARKERSUB", "Marker Sub");}

	public static $plural_name = "MarkerSubs";
		function i18n_plural_name() { return _t("MarkerSubBoard.MARKERSUBS", "Marker Subs");}

	public static $searchable_fields = array(
		"Name" => "PartialMatchFilter",
		"Code" => "PartialMatchFilter"
	);

	public static $field_labels = array(
		"Name" => "Name"
	);

	public static $summary_fields = array(
		"Name" => "Name",
		"Marker.Title"
	);

	public static $description = "A Marker within a Sub Markers.";

	public static function show() {
		return MarkerSubBoard::get()->First() ? true : false;
	}

	function getCMSFields() {
		$fields = parent::getCMSFields();
//                $gridFieldConfig = GridFieldConfig_RelationEditor::create()->addComponents(
//			new GridFieldDeleteAction('unlinkrelation')
//		);
//	
//                $gridFieldConfig->getComponentByType('GridFieldDataColumns')->setDisplayFields(array(
//                    'Marker.Title'=> 'Marker',
//                    'Code' => 'Code',
//                    'Name' => 'Name'                  
//                )); 
//                
//		$gridfield = new GridField("Marker", "MarkerBoard", $this->MarkerSubBoard(), $gridFieldConfig);
//		$fields->addFieldToTab('Root.Markers', $gridfield);
		return $fields;
	}

        public function validate() {
            $valid = parent::validate();
            if($this->Code == '') {
                $this->Code = 'Please Enter Code';
                $valid->error(_t('',
                     '"{field}" is required',
                     array('field' => 'Code')
                ));
            }
            
            if($this->MarkerID == '') {
                $this->MarkerID = 'Please Select Marker';
                $valid->error(_t('',
                     '"{field}" is required',
                     array('field' => 'MarkerID')
                ));
            }
            
//            foreach(self::$required_fields as $field) {
//                if (empty($this->$field)) {
//                        $valid->error(_t('',
//                                '"{field}" is required',
//                                        array('field' => isset(self::$field_labels[$field])?self::$field_labels[$field]:$field)
//                        ));
//                }
//            }
                
            return $valid;
    }
    
	public static function find_title($markersubID) {
		$options = self::get_default_array();
		// check if code was provided, and is found in the country array
		if($options && isset($options[$markersubID])) {
			return $options[$markersubID];
		}
		else {
			return "";
		}
	}

	protected static function get_default_array() {
		$defaultArray = array();
		$markersubs = MarkerSubBoard::get()
			->Exclude(array("Enabled" => 1));
		$defaultMarkerSub = MarkerSubBoard::get_markersub_id();
		if($defaultMarkerSub) {
			$markersubs = $markersubs->Filter(array("MarkerID" => MarkerBoard::get_markersub_id()));
		}
		if($markersubs && $markersubs->count()) {
			foreach($markersubs as $markersub) {
				$defaultArray[$markersub->ID] = $markersub->Name;
			}
		}
		return $defaultArray;
	}
}

